@@ -45,7 +45,8 @@ anomaly_map <- function(config = NULL,
                         attach = FALSE,
                         infile_attach = "auto",
                         dwd_logo = FALSE,
-                        verbose = TRUE) {
+                        verbose = TRUE,
+                        nc = NULL) {
   # Call central argument parser
   arguments_necessary <- methods::formalArgs(parse_arguments)
   arguments <- as.list(match.call())
@@ -86,6 +87,7 @@ anomaly_map <- function(config = NULL,
   new_infile <- parsedArguments$new_infile
   dwd_logo <- parsedArguments$dwd_logo
   verbose <- parsedArguments$verbose
+  nc <- parsedArguments$nc
   
   if (attach) {
     attach_file(variable = variable,
@@ -106,7 +108,8 @@ anomaly_map <- function(config = NULL,
       end_date = end_date,
       mean_value = mean_value,
       temp_dir = temp_dir,
-      verbose = verbose
+      verbose = verbose,
+      nc = nc
     )
   } else
   {
@@ -118,7 +121,8 @@ anomaly_map <- function(config = NULL,
       end_date = end_date,
       accumulate = accumulate,
       temp_dir = temp_dir,
-      verbose = verbose
+      verbose = verbose,
+      nc = nc
     )
   }
  
@@ -138,7 +142,8 @@ anomaly_map <- function(config = NULL,
       lat_min = lat_min,
       lat_max = lat_max,
       mean_value = mean_value,
-      verbose = verbose
+      verbose = verbose,
+      nc = nc
     )
   } else {
     climatology_file <- calculate_climatology(
@@ -155,7 +160,8 @@ anomaly_map <- function(config = NULL,
     lat_min = lat_min,
     lat_max = lat_max,
     accumulate = accumulate,
-    verbose = verbose
+    verbose = verbose,
+    nc = nc
     )
   }
   
